==> freediams_0.5.4.orig.tar.gz: freediams-0.5.4/global_resources/translations/icdplugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>ICD</name>
    <message>
        <source>ICD Collection file (*.icd)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recreate ICD10 database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ICD10 database informations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ICD10 search method</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search by label</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ICD models modes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search by code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toggle code selector</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print ICD10 code collection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Selector: simple list mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Selector: full mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Collection: simple list mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Collection: full mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ICD10 code collection</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ICD::IcdCentralWidget</name>
    <message>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Collection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can not add this code to your collection.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This code is already included or is excluded by the current collection code.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Opening an ICD Collection : merge or replace ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There is an ICD Collection inside the editor, do you to replace it or to add the opened collection ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Replace collection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add to collection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open a collection</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ICD::IcdCodeSelector</name>
    <message>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ICD::IcdCollectionModel</name>
    <message>
        <source>Can not add this code: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can not add this Association: %1-%2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ICD::IcdDatabase</name>
    <message>
        <source>Searching databases into dir %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ICD10 database corrupted, please contact your administrator.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ICD::IcdDownloader</name>
    <message>
        <source>The ICD10 database can not be created. The application will not work properly.
Please contact the dev team.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Downloading ICD10 raw sources...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Starting ICD10 database creation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to unzip ICD10 raw sources (%1)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ICD::IcdViewer</name>
    <message>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CODE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TextLabel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dependencies</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Includes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Excludes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> freediams_0.6.0.orig.tar.gz: freediams-0.6.0/global_resources/translations/icdplugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>ICD</name>
    <message>
        <source>ICD Collection file (*.icd)</source>
        <translation>Collection CIM10 (*.icd)</translation>
    </message>
    <message>
        <source>Recreate ICD10 database</source>
        <translation>Recréer la base de données CIM10</translation>
    </message>
    <message>
        <source>ICD10 database informations</source>
        <translation>Information base de données: CIM10</translation>
    </message>
    <message>
        <source>ICD10 search method</source>
        <translation>Mode de recherche dans la CIM10</translation>
    </message>
    <message>
        <source>Search by label</source>
        <translation>Rechercher par libellé</translation>
    </message>
    <message>
        <source>ICD models modes</source>
        <translation>Modes d&apos;édition CIM10</translation>
    </message>
    <message>
        <source>Search by code</source>
        <translation>Rechercher par code</translation>
    </message>
    <message>
        <source>Toggle code selector</source>
        <translation>Afficher/cacher le sélectionneur de code</translation>
    </message>
    <message>
        <source>Print ICD10 code collection</source>
        <translation>Imprimer la collection CIM10</translation>
    </message>
    <message>
        <source>Selector: simple list mode</source>
        <translation>Mode d&apos;édition : liste simple</translation>
    </message>
    <message>
        <source>Selector: full mode</source>
        <translation>Mode d&apos;édition : complet</translation>
    </message>
    <message>
        <source>Collection: simple list mode</source>
        <translation>Mode d&apos;édition : liste simple de codes</translation>
    </message>
    <message>
        <source>Collection: full mode</source>
        <translation>Mode d&apos;édition : mode collection</translation>
    </message>
    <message>
        <source>ICD10 code collection</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ICD::IcdCentralWidget</name>
    <message>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <source>Collection</source>
        <translation></translation>
    </message>
    <message>
        <source>Can not add this code to your collection.</source>
        <translation>Impossible d&apos;ajouter ce code à votre collection.</translation>
    </message>
    <message>
        <source>This code is already included or is excluded by the current collection code.</source>
        <translation>Ce code est déjà inclus ou est exclus par la collection actuelle.</translation>
    </message>
    <message>
        <source>Opening an ICD Collection : merge or replace ?</source>
        <translation>Ouverture d&apos;une collection CIM10 : ajouter ou remplacer ?</translation>
    </message>
    <message>
        <source>There is an ICD Collection inside the editor, do you to replace it or to add the opened collection ?</source>
        <translation>L&apos;éditeur contient déjà une collection CIM10, voulez-vous la remplacer ou l&apos;ajouter à la collection préexistante ?</translation>
    </message>
    <message>
        <source>Replace collection</source>
        <translation>Remplacer la collection</translation>
    </message>
    <message>
        <source>Add to collection</source>
        <translation>Ajouter à la collection</translation>
    </message>
    <message>
        <source>Open a collection</source>
        <translation>Ouvrir la collection</translation>
    </message>
</context>
<context>
    <name>ICD::IcdCodeSelector</name>
    <message>
        <source>Form</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>ICD::IcdCollectionModel</name>
    <message>
        <source>Can not add this code: %1</source>
        <translation>Impossible d&apos;ajouter le code: %1</translation>
    </message>
    <message>
        <source>Can not add this Association: %1-%2</source>
        <translation>Impossible d&apos;ajouter cette association : %1 - %2</translation>
    </message>
</context>
<context>
    <name>ICD::IcdDatabase</name>
    <message>
        <source>Searching databases into dir %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ICD10 database corrupted, please contact your administrator.</source>
        <translation>La base de données CIM10 est corrompue, veuillez contacter votre administrateur.</translation>
    </message>
</context>
<context>
    <name>ICD::IcdDownloader</name>
    <message>
        <source>The ICD10 database can not be created. The application will not work properly.
Please contact the dev team.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Downloading ICD10 raw sources...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Starting ICD10 database creation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to unzip ICD10 raw sources (%1)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ICD::IcdPlugin</name>
    <message>
        <source>Initializing ICD10 plugin...</source>
        <translation>Initialisation du plugin CIM10...</translation>
    </message>
</context>
<context>
    <name>ICD::IcdViewer</name>
    <message>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <source>CODE</source>
        <translation>Code</translation>
    </message>
    <message>
        <source>TextLabel</source>
        <translation></translation>
    </message>
    <message>
        <source>Dependencies</source>
        <translation>Dépendances</translation>
    </message>
    <message>
        <source>Includes</source>
        <translation>Inclusions</translation>
    </message>
    <message>
        <source>Excludes</source>
        <translation>Exclusions</translation>
    </message>
</context>
</TS>
